@@ -65,9 +65,9 @@ def plot_loo_pit(
     n_unif : int, optional
         Number of datasets to simulate and overlay from the uniform distribution.
     use_hdi : bool, optional
-        Use plot_hdi to fill between hdi values instead of overlaying the uniform distributions.
+        Compute expected hdi values instead of overlaying the sampled uniform distributions.
     credible_interval : float, optional
-        Credible interval of the hdi or of the ECDF theoretical credible interval
+        Theoretical credible interval. Works with ``use_hdi=True`` or ``ecdf=True``.
     figsize : figure size tuple, optional
         If None, size is (8 + numvars, 8 + numvars)
     textsize: int, optional
@@ -86,7 +86,7 @@ def plot_loo_pit(
         Additional keywords passed to ax.plot for overlaid uniform distributions or
         for beta credible interval lines if ``ecdf=True``
     hdi_kwargs : dict, optional
-        Additional keywords passed to az.plot_hdi
+        Additional keywords passed to ax.axhspan
     fill_kwargs : dict, optional
         Additional kwargs passed to ax.fill_between
     backend: str, optional
@@ -168,8 +168,8 @@ def plot_loo_pit(
     p975 = None
     p025 = None
     loo_pit_kde = None
+    hdi_odds = None
     unif = None
-    unif_densities = None
     x_vals = None
 
     if credible_interval is None:
@@ -206,20 +206,19 @@ def plot_loo_pit(
             )
             fill_kwargs.setdefault("label", "{:.3g}% credible interval".format(credible_interval))
     else:
-        loo_pit_kde, _, _ = _fast_kde(loo_pit, xmin=0, xmax=1)
+        loo_pit_kde, xmin, xmax = _fast_kde(loo_pit)
 
         unif = np.random.uniform(size=(n_unif, loo_pit.size))
-        x_vals = np.linspace(0, 1, len(loo_pit_kde))
+        x_vals = np.linspace(xmin, xmax, len(loo_pit_kde))
         if use_hdi:
+            n_obs = loo_pit.size
+            hdi_ = stats.beta(n_obs / 2, n_obs / 2).ppf((1 - credible_interval) / 2)
+            hdi_odds = (hdi_ / (1 - hdi_), (1 - hdi_) / hdi_)
             if hdi_kwargs is None:
                 hdi_kwargs = {}
             hdi_kwargs.setdefault("color", to_hex(hsv_to_rgb(light_color)))
-            hdi_fill_kwargs = hdi_kwargs.pop("fill_kwargs", {})
-            hdi_fill_kwargs.setdefault("label", "Uniform hdi")
-            hdi_kwargs["fill_kwargs"] = hdi_fill_kwargs
-            hdi_kwargs["credible_interval"] = credible_interval
-
-            unif_densities = np.empty((n_unif, len(loo_pit_kde)))
+            hdi_kwargs.setdefault("alpha", 0.35)
+            hdi_kwargs.setdefault("label", "Uniform HDI")
 
     loo_pit_kwargs = dict(
         ax=ax,
@@ -234,8 +233,8 @@ def plot_loo_pit(
         ecdf_fill=ecdf_fill,
         use_hdi=use_hdi,
         x_vals=x_vals,
-        unif_densities=unif_densities,
         hdi_kwargs=hdi_kwargs,
+        hdi_odds=hdi_odds,
         n_unif=n_unif,
         unif=unif,
         plot_unif_kwargs=plot_unif_kwargs,
@@ -253,14 +252,8 @@ def plot_loo_pit(
     backend = backend.lower()
 
     if backend == "bokeh":
-
-        if (
-            loo_pit_kwargs["hdi_kwargs"] is not None
-            and "fill_kwargs" in loo_pit_kwargs["hdi_kwargs"]
-            and loo_pit_kwargs["hdi_kwargs"]["fill_kwargs"] is not None
-            and "label" in loo_pit_kwargs["hdi_kwargs"]["fill_kwargs"]
-        ):
-            loo_pit_kwargs["hdi_kwargs"]["fill_kwargs"].pop("label")
+        if use_hdi:
+            loo_pit_kwargs["hdi_kwargs"].pop("label", None)
         loo_pit_kwargs.pop("legend")
         loo_pit_kwargs.pop("xt_labelsize")
         loo_pit_kwargs.pop("credible_interval")
