@@ -338,15 +338,15 @@ def hpd(
     warnings.warn(("hpd will be deprecated " "Please replace hdi"),)
     return hdi(
         ary,
-        hdi_prob=None,
-        circular=False,
-        multimodal=False,
-        skipna=False,
-        group="posterior",
-        var_names=None,
-        filter_vars=None,
-        coords=None,
-        max_modes=10,
+        hdi_prob,
+        circular,
+        multimodal,
+        skipna,
+        group,
+        var_names,
+        filter_vars,
+        coords,
+        max_modes,
         **kwargs,
     )
 
@@ -365,7 +365,7 @@ def hdi(
     **kwargs,
 ):
     """
-    Calculate highest density interval (HDI) of array for given percentage.
+    Calculate highest density interval (HDI) of array for given probability.
 
     The HDI is the minimum width Bayesian credible interval (BCI).
 
@@ -376,15 +376,15 @@ def hdi(
         Any object that can be converted to an az.InferenceData object.
         Refer to documentation of az.convert_to_dataset for details.
     hdi_prob: float, optional
-        HDI prob for which interval will be computed. Defaults to 0.94.
+        HDI prob for which interval will be computed. Defaults to ``stats.hdi_prob`` rcParam.
     circular: bool, optional
         Whether to compute the hdi taking into account `x` is a circular variable
         (in the range [-np.pi, np.pi]) or not. Defaults to False (i.e non-circular variables).
         Only works if multimodal is False.
-    multimodal: bool
+    multimodal: bool, optional
         If true it may compute more than one hdi interval if the distribution is multimodal and the
         modes are well separated.
-    skipna: bool
+    skipna: bool, optional
         If true ignores nan values when computing the hdi interval. Defaults to false.
     group: str, optional
         Specifies which InferenceData group should be used to calculate hdi.
@@ -403,17 +403,21 @@ def hdi(
     max_modes: int, optional
         Specifies the maximum number of modes for multimodal case.
     kwargs: dict, optional
-        Additional keywords passed to `wrap_xarray_ufunc`.
-        See the docstring of :obj:`wrap_xarray_ufunc method </.stats_utils.wrap_xarray_ufunc>`.
+        Additional keywords passed to :func:`~arviz.wrap_xarray_ufunc`.
 
     Returns
     -------
     np.ndarray or xarray.Dataset, depending upon input
         lower(s) and upper(s) values of the interval(s).
 
+    See Also
+    --------
+    plot_hdi : Plot HDI intervals for regression data.
+    xarray.Dataset.quantile : Calculate quantiles of array for given probabilities.
+
     Examples
     --------
-    Calculate the hdi of a Normal random variable:
+    Calculate the HDI of a Normal random variable:
 
     .. ipython::
 
@@ -422,7 +426,7 @@ def hdi(
            ...: data = np.random.normal(size=2000)
            ...: az.hdi(data, hdi_prob=.68)
 
-    Calculate the hdi of a dataset:
+    Calculate the HDI of a dataset:
 
     .. ipython::
 
@@ -430,13 +434,13 @@ def hdi(
            ...: data = az.load_arviz_data('centered_eight')
            ...: az.hdi(data)
 
-    We can also calculate the hdi of some of the variables of dataset:
+    We can also calculate the HDI of some of the variables of dataset:
 
     .. ipython::
 
         In [1]: az.hdi(data, var_names=["mu", "theta"])
 
-    If we want to calculate the hdi over specified dimension of dataset,
+    If we want to calculate the HDI over specified dimension of dataset,
     we can pass `input_core_dims` by kwargs:
 
     .. ipython::
@@ -476,7 +480,12 @@ def hdi(
         return hdi_data[~np.isnan(hdi_data).all(axis=1), :] if multimodal else hdi_data
 
     if isarray and ary.ndim == 2:
-        kwargs.setdefault("input_core_dims", [["chain"]])
+        warnings.warn(
+            "hdi currently interprets 2d data as (draw, shape) but this will change in "
+            "a future release to (chain, draw) for coherence with other functions",
+            FutureWarning,
+        )
+        ary = np.expand_dims(ary, 0)
 
     ary = convert_to_dataset(ary, group=group)
     if coords is not None:
@@ -484,7 +493,10 @@ def hdi(
     var_names = _var_names(var_names, ary, filter_vars)
     ary = ary[var_names] if var_names else ary
 
-    hdi_data = _wrap_xarray_ufunc(func, ary, func_kwargs=func_kwargs, **kwargs)
+    hdi_coord = xr.DataArray(["lower", "higher"], dims=["hdi"], attrs=dict(hdi_prob=hdi_prob))
+    hdi_data = _wrap_xarray_ufunc(func, ary, func_kwargs=func_kwargs, **kwargs).assign_coords(
+        {"hdi": hdi_coord}
+    )
     hdi_data = hdi_data.dropna("mode", how="all") if multimodal else hdi_data
     return hdi_data.x.values if isarray else hdi_data
 
@@ -527,7 +539,7 @@ def _hdi(ary, hdi_prob, circular, skipna):
 
 
 def _hdi_multimodal(ary, hdi_prob, skipna, max_modes):
-    """Compute hdi if the distribution is multimodal."""
+    """Compute HDI if the distribution is multimodal."""
     ary = ary.flatten()
     if skipna:
         ary = ary[~np.isnan(ary)]
@@ -1029,7 +1041,7 @@ def summary(
         If True, use the statistics returned by ``stat_funcs`` in addition to, rather than in place
         of, the default statistics. This is only meaningful when ``stat_funcs`` is not None.
     hdi_prob: float, optional
-        hdi interval to compute. Defaults to 0.94. This is only meaningful when ``stat_funcs`` is
+        HDI interval to compute. Defaults to 0.94. This is only meaningful when ``stat_funcs`` is
         None.
     order: {"C", "F"}
         If fmt is "wide", use either C or F unpacking order. Defaults to C.
@@ -1161,13 +1173,9 @@ def summary(
 
         sd = posterior.std(dim=("chain", "draw"), ddof=1, skipna=skipna)
 
-        hdi_lower, hdi_higher = xr.apply_ufunc(
-            _make_ufunc(hdi, n_output=2),
-            posterior,
-            kwargs=dict(hdi_prob=hdi_prob, multimodal=False, skipna=skipna),
-            input_core_dims=(("chain", "draw"),),
-            output_core_dims=tuple([] for _ in range(2)),
-        )
+        hdi_post = hdi(posterior, hdi_prob=hdi_prob, multimodal=False, skipna=skipna)
+        hdi_lower = hdi_post.sel(hdi="lower", drop=True)
+        hdi_higher = hdi_post.sel(hdi="higher", drop=True)
 
     if include_circ:
         nan_policy = "omit" if skipna else "propagate"
@@ -1199,13 +1207,9 @@ def summary(
             input_core_dims=(("chain", "draw"),),
         )
 
-        circ_hdi_lower, circ_hdi_higher = xr.apply_ufunc(
-            _make_ufunc(hdi, n_output=2),
-            posterior,
-            kwargs=dict(hdi_prob=hdi_prob, circular=True, skipna=skipna),
-            input_core_dims=(("chain", "draw"),),
-            output_core_dims=tuple([] for _ in range(2)),
-        )
+        circ_hdi = hdi(posterior, hdi_prob=hdi_prob, circular=True, skipna=skipna)
+        circ_hdi_lower = circ_hdi.sel(hdi="lower", drop=True)
+        circ_hdi_higher = circ_hdi.sel(hdi="higher", drop=True)
 
     if kind in ["all", "diagnostics"]:
         mcse_mean, mcse_sd, ess_mean, ess_sd, ess_bulk, ess_tail, r_hat = xr.apply_ufunc(
