@@ -16,6 +16,7 @@ from ...plots.plot_utils import (
     xarray_to_ndarray,
     xarray_var_iter,
     vectorized_to_hex,
+    _dealiase_sel_kwargs,
 )
 from ...rcparams import rc_context
 from ...numeric_utils import get_bins
@@ -244,3 +245,22 @@ def test_vectorized_to_hex_scalar(c_values):
 def test_vectorized_to_hex_array(c_values):
     output = vectorized_to_hex(c_values)
     assert np.all([item == "#0000ff" for item in output])
+
+
+def test_dealiase_sel_kwargs():
+    """Check _dealiase_sel_kwargs behaviour.
+
+    Makes sure kwargs are overwritten when necessary even with alias involved and that
+    they are not modified when not included in props.
+    """
+    kwargs = {"linewidth": 3, "alpha": 0.4, "line_color": "red"}
+    props = {"lw": [1, 2, 4, 5], "linestyle": ["-", "--", ":"]}
+    res = _dealiase_sel_kwargs(kwargs, props, 2)
+    assert "linewidth" in res
+    assert res["linewidth"] == 4
+    assert "linestyle" in res
+    assert res["linestyle"] == ":"
+    assert "alpha" in res
+    assert res["alpha"] == 0.4
+    assert "line_color" in res
+    assert res["line_color"] == "red"
