@@ -35,11 +35,12 @@ from ...plots import (  # pylint: disable=wrong-import-position
     plot_parallel,
     plot_posterior,
     plot_ppc,
+    plot_dist_comparison,
     plot_rank,
     plot_trace,
     plot_violin,
 )
-from ...stats import compare, loo, waic  # pylint: disable=wrong-import-position
+from ...stats import compare, loo, waic, hdi  # pylint: disable=wrong-import-position
 
 # Skip tests if bokeh not installed
 bkp = importorskip("bokeh.plotting")  # pylint: disable=invalid-name
@@ -126,8 +127,8 @@ def test_plot_density_bad_kwargs(models):
         {},
         {"var_names": "mu"},
         {"var_names": ["mu", "tau"]},
-        {"combined": True},
-        {"compact": True},
+        {"combined": True, "rug": True},
+        {"compact": True, "legend": True},
         {"combined": True, "compact": True, "legend": True},
         {"divergences": "top"},
         {"divergences": False},
@@ -482,16 +483,20 @@ def test_plot_forest_bad(models, model_fits):
     "kwargs",
     [
         {"color": "C5", "circular": True},
-        {"fill_kwargs": {"alpha": 0}},
+        {"hdi_data": True, "fill_kwargs": {"alpha": 0}},
         {"plot_kwargs": {"alpha": 0}},
         {"smooth_kwargs": {"window_length": 33, "polyorder": 5, "mode": "mirror"}},
-        {"smooth": False},
+        {"hdi_data": True, "smooth": False, "color": "xkcd:jade"},
     ],
 )
 def test_plot_hdi(models, data, kwargs):
-    axis = plot_hdi(
-        data["y"], models.model_1.posterior["theta"], backend="bokeh", show=False, **kwargs
-    )
+    hdi_data = kwargs.pop("hdi_data", None)
+    y_data = models.model_1.posterior["theta"]
+    if hdi_data:
+        hdi_data = hdi(y_data)
+        axis = plot_hdi(data["y"], hdi_data=hdi_data, backend="bokeh", show=False, **kwargs)
+    else:
+        axis = plot_hdi(data["y"], y_data, backend="bokeh", show=False, **kwargs)
     assert axis
 
 
@@ -603,8 +608,8 @@ def test_plot_khat_bad_input(models):
         {},
         {"n_unif": 50},
         {"use_hdi": True, "color": "gray"},
-        {"use_hdi": True, "credible_interval": 0.68, "plot_kwargs": {"alpha": 0.9}},
-        {"use_hdi": True, "hdi_kwargs": {"smooth": False}},
+        {"use_hdi": True, "credible_interval": 0.68},
+        {"use_hdi": True, "hdi_kwargs": {"line_dash": "dashed", "alpha": 0}},
         {"ecdf": True},
         {"ecdf": True, "ecdf_fill": False, "plot_unif_kwargs": {"line_dash": "--"}},
         {"ecdf": True, "credible_interval": 0.97, "fill_kwargs": {"color": "red"}},
@@ -956,3 +961,8 @@ def test_plot_posterior_point_estimates(models, point_estimate):
 def test_plot_rank(models, kwargs):
     axes = plot_rank(models.model_1, backend="bokeh", show=False, **kwargs)
     assert axes.shape
+
+
+def test_plot_dist_comparison_warn(models):
+    with pytest.raises(NotImplementedError, match="The bokeh backend.+Use matplotlib bakend."):
+        plot_dist_comparison(models.model_1, backend="bokeh")
